@@ -94,6 +94,7 @@ impl ClusterBuilder {
     ///
     /// [`EventTypeFlags::SHARD_PAYLOAD`]: crate::EventTypeFlags::SHARD_PAYLOAD
     #[allow(clippy::missing_const_for_fn)]
+    #[must_use = "has no effect if not built"]
     pub fn event_types(mut self, event_types: EventTypeFlags) -> Self {
         self.1 = self.1.event_types(event_types);
 
@@ -101,6 +102,7 @@ impl ClusterBuilder {
     }
 
     /// Set the URL that will be used to connect to the gateway.
+    #[must_use = "has no effect if not built"]
     pub fn gateway_url(mut self, gateway_url: Option<String>) -> Self {
         self.1 = self.1.gateway_url(gateway_url);
 
@@ -114,6 +116,7 @@ impl ClusterBuilder {
     /// information.
     ///
     /// Defaults to a new, default HTTP client is used.
+    #[must_use = "has no effect if not built"]
     pub fn http_client(mut self, http_client: Arc<Client>) -> Self {
         self.1 = self.1.http_client(http_client);
 
@@ -149,6 +152,7 @@ impl ClusterBuilder {
     /// # Ok(()) }
     /// ```
     #[allow(clippy::missing_const_for_fn)]
+    #[must_use = "has no effect if not built"]
     pub fn identify_properties(mut self, identify_properties: IdentifyProperties) -> Self {
         self.1 = self.1.identify_properties(identify_properties);
 
@@ -179,12 +183,27 @@ impl ClusterBuilder {
     /// Set the presence to use when identifying with the gateway.
     ///
     /// Refer to the shard's [`ShardBuilder::presence`] for more information.
+    #[must_use = "has no effect if not built"]
     pub fn presence(mut self, presence: UpdatePresencePayload) -> Self {
         self.1 = self.1.presence(presence);
 
         self
     }
 
+    /// Set whether or not outgoing payloads will be ratelimited.
+    ///
+    /// Useful when running behind a proxy gateway. Running without a
+    /// functional ratelimiter **will** get you ratelimited.
+    ///
+    /// Defaults to being enabled.
+    #[allow(clippy::missing_const_for_fn)]
+    #[must_use = "has no effect if not built"]
+    pub fn ratelimit_payloads(mut self, ratelimit_payloads: bool) -> Self {
+        self.1 = self.1.ratelimit_payloads(ratelimit_payloads);
+
+        self
+    }
+
     /// Set specific shard presences to use when identifying with the gateway.
     ///
     /// Accepts a closure. The closure accepts a [`u64`] and returns an
@@ -192,6 +211,7 @@ impl ClusterBuilder {
     /// by [`presence`], even if the provided closure returns [`None`].
     ///
     /// [`presence`]: Self::presence
+    #[must_use = "has no effect if not built"]
     pub fn shard_presence<F>(mut self, shard_presence: F) -> Self
     where
         F: Fn(u64) -> Option<UpdatePresencePayload> + Send + Sync + 'static,
@@ -230,6 +250,7 @@ impl ClusterBuilder {
     /// # Ok(()) }
     /// ```
     #[allow(clippy::missing_const_for_fn)]
+    #[must_use = "has no effect if not built"]
     pub fn shard_scheme(mut self, scheme: ShardScheme) -> Self {
         self.0.shard_scheme = scheme;
 
@@ -244,6 +265,7 @@ impl ClusterBuilder {
     /// Refer to the [`queue`] module for more information.
     ///
     /// [`queue`]: crate::queue
+    #[must_use = "has no effect if not built"]
     pub fn queue(mut self, queue: Arc<dyn Queue>) -> Self {
         self.0.queue = Arc::clone(&queue);
         self.1 = self.1.queue(queue);
@@ -260,6 +282,7 @@ impl ClusterBuilder {
     /// to resume. If their sessions are invalid they will have to re-identify
     /// to initialize a new session.
     #[allow(clippy::missing_const_for_fn)]
+    #[must_use = "has no effect if not built"]
     pub fn resume_sessions(mut self, resume_sessions: HashMap<u64, ResumeSession>) -> Self {
         self.0.resume_sessions = resume_sessions;
         self
